pub enum Mutation {
AddNode(NodeSnapshot),
RemoveNode(NodeId),
AddLink(SnapshotEdge),
RemoveLink(LinkId),
}Available on crate feature
topology only.Expand description
A pure-data edit applicable to a TopologySnapshot via
TopologySnapshot::apply.
Mutations are themselves serializable, so a session store can log/replicate
a stream of Mutations and replay them onto a baseline snapshot.
Variants
AddNode(NodeSnapshot)
Add (or replace) the node with the given snapshot.
RemoveNode(NodeId)
Remove the node with the given id (and its incident edges).
AddLink(SnapshotEdge)
Add the given edge.
RemoveLink(LinkId)
Remove the edge at the given positional LinkId.